#!/bin/sh -e
### BEGIN INIT INFO
# Provides:          dreamchess 
# Required-Start:    $local_fs $remote_fs $network
# Required-Stop:     $local_fs $remote_fs $network
# Default-Start:     2 3 4 5
# Default-Stop:      0 1 6
# Short-Description: Start or stop the dreamchess 
### END INIT INFO

PKG_PATH=/usr/local/AppCentral/dreamchess
ASPORTAL_PATH=/usr/local/AppCentral/asportal
ASPORTAL_STAT="`apkg --info-installed asportal | grep 'Enabled:' | awk '{print $2}'`"

NAME=dreamchess 
RUN_dreamchess=$PKG_PATH/run_dreamchess.sh


[ -x $RUN_dreamchess ] || exit 0

. /lib/lsb/init-functions

start_daemon () {

    sed -i 's/\"show\":\".*\"/\"show\":\"true\"/g' $PKG_PATH/asportal/dreamchess.json

	if [ -e "$ASPORTAL_PATH" ]; then
	     if [ "Yes" == "$ASPORTAL_STAT" ]; then
	     	$ASPORTAL_PATH/CONTROL/start-stop.sh reload &
 	     fi
	fi

}

stop_daemon () {

	killall dreamchess 

    sed -i 's/\"show\":\".*\"/\"show\":\"false\"/g'  $PKG_PATH/asportal/dreamchess.json

    if [ -e "$ASPORTAL_PATH" ]; then
        if [ "Yes" == "$ASPORTAL_STAT" ]; then
            $ASPORTAL_PATH/CONTROL/start-stop.sh reload &
	    fi
	fi
}

suspend_daemon() {
   echo "suspend dreamchess"
}

resume_daemon() {
   echo "resume dreamchess"
}


case "$1" in
    start)
        log_daemon_msg "Starting daemon" "$NAME"
         [ ! -d /usr/share/games ] && mkdir /usr/share/games
         [ ! -d /usr/share/games/dreamchess ] && ln -sf /usr/local/AppCentral/dreamchess/usr/share/games/dreamchess  /usr/share/games
        start_daemon
        log_end_msg 0
        ;;
    stop)
        log_daemon_msg "Stopping daemon" "$NAME"
        [ -d /usr/share/games/dreamchess ] && rm  /usr/share/games/dreamchess
        stop_daemon
        log_end_msg 0
        ;;
    reload)
        log_daemon_msg "Reloading daemon" "$NAME"

	if [ "`pidof quarry`" ];then
           stop_daemon
	fi
        start_daemon
        log_end_msg 0
        ;;
    suspend)
        suspend_daemon
        ;;
    resume)
        resume_daemon
        ;;
    restart|force-reload)
        log_daemon_msg "Restarting daemon" "$NAME"
        if [ "`pidof quarry`" ]; then
	    stop_daemon
	fi
        start_daemon
        log_end_msg 0
        ;;
    debug)
        ;;
    *)
        echo "Usage: /etc/init.d/$NAME {start|stop|reload|force-reload|restart}"
        exit 2
        ;;
esac

if [ "$1" != "debug" ] ; then
    exit 0
fi
